%bcond_with bootstrap

%global bundled_slf4j_version 1.7.30
%global homedir %{_datadir}/%{name}%{?maven_version_suffix}
%global confdir %{_sysconfdir}/%{name}%{?maven_version_suffix}

Name:           maven
Epoch:          1
Version:        3.8.5
Release:        %mkrel 2
Summary:        Java project management and project comprehension tool
# maven itself is ASL 2.0
# bundled slf4j is MIT
License:        ASL 2.0 and MIT
URL:            https://maven.apache.org/
BuildArch:      noarch
Group:          Development/Java
ExclusiveArch:  aarch64 ppc64le s390x x86_64 noarch

Source0:        https://archive.apache.org/dist/%{name}/%{name}-3/%{version}/source/apache-%{name}-%{version}-src.tar.gz
Source1:        maven-bash-completion
Source2:        mvn.1

Patch1:         0001-Adapt-mvn-script.patch
# Downstream-specific, avoids dependency on logback
# Used only when %%without logback is in effect
Patch2:         0002-Invoke-logback-via-reflection.patch
Patch3:         0003-Use-non-shaded-HTTP-wagon.patch
Patch4:         0004-Remove-dependency-on-powermock.patch
Patch5:         0005-Port-to-maven-resolver-1.7.2.patch
# XMvn needs to be ported to Maven 3.8.5
# For now restore backwards compatibility with Maven 3.8.4
Patch6:         0006-Restore-DefaultModelValidator-compatibility-with-Mav.patch

%if %{with bootstrap}
BuildRequires:  javapackages-bootstrap-openjdk8
%else
BuildRequires:  maven-local-openjdk8
BuildRequires:  mvn(com.google.inject:guice::no_aop:)
BuildRequires:  mvn(commons-cli:commons-cli)
BuildRequires:  mvn(commons-jxpath:commons-jxpath)
BuildRequires:  mvn(javax.annotation:jsr250-api)
BuildRequires:  mvn(javax.inject:javax.inject)
BuildRequires:  mvn(junit:junit)
BuildRequires:  maven-surefire-provider-junit
BuildRequires:  mvn(org.apache.commons:commons-lang3)
BuildRequires:  mvn(org.apache.maven:maven-parent:pom:)
BuildRequires:  mvn(org.apache.maven.plugins:maven-assembly-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-dependency-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-failsafe-plugin)
BuildRequires:  mvn(org.apache.maven.resolver:maven-resolver-api)
BuildRequires:  mvn(org.apache.maven.resolver:maven-resolver-connector-basic)
BuildRequires:  mvn(org.apache.maven.resolver:maven-resolver-impl)
BuildRequires:  mvn(org.apache.maven.resolver:maven-resolver-spi)
BuildRequires:  mvn(org.apache.maven.resolver:maven-resolver-transport-wagon)
BuildRequires:  mvn(org.apache.maven.resolver:maven-resolver-util)
BuildRequires:  mvn(org.apache.maven.shared:maven-shared-utils)
BuildRequires:  mvn(org.apache.maven.wagon:wagon-file)
BuildRequires:  mvn(org.apache.maven.wagon:wagon-http)
BuildRequires:  mvn(org.apache.maven.wagon:wagon-provider-api)
BuildRequires:  mvn(org.codehaus.modello:modello-maven-plugin)
BuildRequires:  mvn(org.codehaus.mojo:build-helper-maven-plugin)
BuildRequires:  mvn(org.codehaus.mojo:extra-enforcer-rules)
BuildRequires:  mvn(org.codehaus.plexus:plexus-classworlds)
BuildRequires:  mvn(org.codehaus.plexus:plexus-component-annotations)
BuildRequires:  mvn(org.codehaus.plexus:plexus-component-metadata)
BuildRequires:  mvn(org.codehaus.plexus:plexus-interpolation)
BuildRequires:  mvn(org.codehaus.plexus:plexus-utils)
BuildRequires:  mvn(org.eclipse.sisu:org.eclipse.sisu.inject)
BuildRequires:  mvn(org.eclipse.sisu:org.eclipse.sisu.plexus)
BuildRequires:  mvn(org.eclipse.sisu:sisu-maven-plugin)
BuildRequires:  mvn(org.fusesource.jansi:jansi)
BuildRequires:  mvn(org.mockito:mockito-core)
BuildRequires:  mvn(org.slf4j:jcl-over-slf4j)
BuildRequires:  mvn(org.slf4j:slf4j-api)
BuildRequires:  mvn(org.slf4j:slf4j-simple)
BuildRequires:  mvn(org.sonatype.plexus:plexus-cipher)
BuildRequires:  mvn(org.sonatype.plexus:plexus-sec-dispatcher)
BuildRequires:  mvn(org.xmlunit:xmlunit-core)
BuildRequires:  mvn(org.xmlunit:xmlunit-matchers)
%endif

# XXX
#BuildRequires:  mvn(org.slf4j:slf4j-simple::sources:) = %{bundled_slf4j_version}
%if %{without bootstrap}
BuildRequires:  mvn(org.slf4j:slf4j-simple::sources:)
%endif

Requires: %{name}-lib = %{epoch}:%{version}-%{release}
Requires: %{name}-jdk-binding = %{epoch}:%{version}-%{release}
Suggests: %{name}-openjdk17 = %{epoch}:%{version}-%{release}

Requires(post): alternatives
Requires(postun): alternatives

%description
Maven is a software project management and comprehension tool. Based on the
concept of a project object model (POM), Maven can manage a project's build,
reporting and documentation from a central piece of information.

%package lib
Summary:        Core part of Maven
# If XMvn is part of the same RPM transaction then it should be
# installed first to avoid triggering rhbz#1014355.
OrderWithRequires: xmvn-minimal

# Maven upstream uses patched version of SLF4J.  They unpack
# slf4j-simple-sources.jar, apply non-upstreamable, Maven-specific
# patch (using a script written in Groovy), compile and package as
# maven-slf4j-provider.jar, together with Maven-specific additions.
Provides:       bundled(slf4j) = %{bundled_slf4j_version}

%description lib
Core part of Apache Maven that can be used as a library.

%package openjdk8
Summary:        OpenJDK 8 binding for Maven
RemovePathPostfixes: -openjdk8
Provides: maven-jdk-binding = %{epoch}:%{version}-%{release}
Requires: maven = %{epoch}:%{version}-%{release}
Requires: java-1.8.0-openjdk-devel
Conflicts: maven-jdk-binding

%description openjdk8
Configures Maven to run with OpenJDK 8.

%package openjdk11
Summary:        OpenJDK 11 binding for Maven
RemovePathPostfixes: -openjdk11
Provides: maven-jdk-binding = %{epoch}:%{version}-%{release}
Requires: maven = %{epoch}:%{version}-%{release}
Requires: java-11-openjdk-devel
Conflicts: maven-jdk-binding

%description openjdk11
Configures Maven to run with OpenJDK 11.

%package openjdk17
Summary:        OpenJDK 17 binding for Maven
RemovePathPostfixes: -openjdk17
Provides: maven-jdk-binding = %{epoch}:%{version}-%{release}
Requires: maven = %{epoch}:%{version}-%{release}
Requires: java-17-openjdk-devel
Conflicts: maven-jdk-binding

%description openjdk17
Configures Maven to run with OpenJDK 17.

%{?javadoc_package}

%prep
%setup -q -n apache-%{name}-%{version}

find -name '*.java' -exec sed -i 's/\r//' {} +
find -name 'pom.xml' -exec sed -i 's/\r//' {} +

%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1

# not really used during build, but a precaution
find -name '*.jar' -not -path '*/test/*' -delete
find -name '*.class' -delete
find -name '*.bat' -delete

%pom_remove_dep -r :powermock-reflect

sed -i 's:\r::' apache-maven/src/conf/settings.xml

# Downloads dependency licenses from the Internet and aggregates them.
# We already ship the licenses in their respective packages.
rm apache-maven/src/main/appended-resources/META-INF/LICENSE.vm

# Disable plugins which are not useful for us
%pom_remove_plugin -r :animal-sniffer-maven-plugin
%pom_remove_plugin -r :apache-rat-plugin
%pom_remove_plugin -r :maven-site-plugin
%pom_remove_plugin -r :buildnumber-maven-plugin
sed -i "
/buildNumber=/ {
  s/=.*/=Red Hat %{version}-%{release}/
  s/%{dist}$//
}
/timestamp=/ d
" `find -name build.properties`

%mvn_package :apache-maven __noinstall

%pom_change_dep :jansi :::runtime maven-embedder
%pom_remove_dep -r :logback-classic

%mvn_alias :maven-resolver-provider :maven-aether-provider

%pom_xpath_inject 'pom:build/pom:plugins' '
<plugin>
	<groupId>org.eclipse.sisu</groupId>
	<artifactId>sisu-maven-plugin</artifactId>
</plugin>' maven-model-builder/pom.xml

%build
%mvn_build -- -Dproject.build.sourceEncoding=UTF-8

mkdir m2home
(cd m2home
    tar --delay-directory-restore -xvf ../apache-maven/target/*tar.gz
)


%install
%mvn_install

export M2_HOME=$(pwd)/m2home/apache-maven-%{version}%{?ver_add}

install -d -m 755 %{buildroot}%{homedir}/conf
install -d -m 755 %{buildroot}%{confdir}
install -d -m 755 %{buildroot}%{_datadir}/bash-completion/completions/

cp -a $M2_HOME/{bin,lib,boot} %{buildroot}%{homedir}/
%if %{without bootstrap}
xmvn-subst -s -R %{buildroot} -s %{buildroot}%{homedir}
%endif

# maven uses this hardcoded path in its launcher to locate jansi so we symlink it
ln -s %{_prefix}/lib/jansi/libjansi.so %{buildroot}%{homedir}/lib/jansi-native/

install -p -m 644 %{SOURCE2} %{buildroot}%{homedir}/bin/
gzip -9 %{buildroot}%{homedir}/bin/mvn.1
install -p -m 644 %{SOURCE1} %{buildroot}%{_datadir}/bash-completion/completions/mvn%{?maven_version_suffix}
mv $M2_HOME/bin/m2.conf %{buildroot}%{_sysconfdir}/m2%{?maven_version_suffix}.conf
ln -sf %{_sysconfdir}/m2%{?maven_version_suffix}.conf %{buildroot}%{homedir}/bin/m2.conf
mv $M2_HOME/conf/settings.xml %{buildroot}%{confdir}/
ln -sf %{confdir}/settings.xml %{buildroot}%{homedir}/conf/settings.xml
mv $M2_HOME/conf/logging %{buildroot}%{confdir}/
ln -sf %{confdir}/logging %{buildroot}%{homedir}/conf

# Ghosts for alternatives
install -d -m 755 %{buildroot}%{_bindir}/
install -d -m 755 %{buildroot}%{_mandir}/man1/
touch %{buildroot}%{_bindir}/{mvn,mvnDebug}
touch %{buildroot}%{_mandir}/man1/{mvn,mvnDebug}.1

# Versioned commands and manpages
%if 0%{?maven_version_suffix:1}
ln -s %{homedir}/bin/mvn %{buildroot}%{_bindir}/mvn%{maven_version_suffix}
ln -s %{homedir}/bin/mvnDebug %{buildroot}%{_bindir}/mvnDebug%{maven_version_suffix}
ln -s %{homedir}/bin/mvn.1.gz %{buildroot}%{_mandir}/man1/mvn%{maven_version_suffix}.1.gz
ln -s %{homedir}/bin/mvnDebug.1.gz %{buildroot}%{_mandir}/man1/mvnDebug%{maven_version_suffix}.1.gz
%endif

# JDK bindings
install -d -m 755 %{buildroot}%{_javaconfdir}/
echo JAVA_HOME=%{_jvmlibdir}/java-1.8.0-openjdk >%{buildroot}%{_javaconfdir}/maven.conf-openjdk8
echo JAVA_HOME=%{_jvmlibdir}/java-11-openjdk >%{buildroot}%{_javaconfdir}/maven.conf-openjdk11
echo JAVA_HOME=%{_jvmlibdir}/java-17-openjdk >%{buildroot}%{_javaconfdir}/maven.conf-openjdk17


%post
update-alternatives --install %{_bindir}/mvn mvn %{homedir}/bin/mvn %{?maven_alternatives_priority}0 \
--slave %{_bindir}/mvnDebug mvnDebug %{homedir}/bin/mvnDebug \
--slave %{_mandir}/man1/mvn.1.gz mvn1 %{homedir}/bin/mvn.1.gz \
--slave %{_mandir}/man1/mvnDebug.1.gz mvnDebug1 %{homedir}/bin/mvn.1.gz \

%postun
if [[ $1 -eq 0 ]]; then update-alternatives --remove mvn %{homedir}/bin/mvn; fi

%files lib -f .mfiles
%doc README.md
%license LICENSE NOTICE
%{homedir}
%exclude %{homedir}/bin/mvn*
%dir %{confdir}
%dir %{confdir}/logging
%config(noreplace) %{_sysconfdir}/m2%{?maven_version_suffix}.conf
%config(noreplace) %{confdir}/settings.xml
%config(noreplace) %{confdir}/logging/simplelogger.properties

%files
%{homedir}/bin/mvn*
%ghost %{_bindir}/mvn
%ghost %{_bindir}/mvnDebug
%{_datadir}/bash-completion
%ghost %{_mandir}/man1/mvn.1.xz
%ghost %{_mandir}/man1/mvnDebug.1.xz
%if 0%{?maven_version_suffix:1}
%{_bindir}/mvn%{maven_version_suffix}
%{_bindir}/mvnDebug%{maven_version_suffix}
%{_mandir}/man1/mvn%{maven_version_suffix}.1.*
%{_mandir}/man1/mvnDebug%{maven_version_suffix}.1.*
%endif

%files openjdk8
%config %{_javaconfdir}/maven.conf-openjdk8

%files openjdk11
%config %{_javaconfdir}/maven.conf-openjdk11

%files openjdk17
%config %{_javaconfdir}/maven.conf-openjdk17




%changelog
* Mon Jul 25 2022 neoclust <neoclust> 1:3.8.5-2.mga9
+ Revision: 1871463
- Rebuild w/o bootstrap

* Sun Jul 24 2022 neoclust <neoclust> 1:3.8.5-1.mga9
+ Revision: 1870611
- New version 3.8.5
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Mon Mar 01 2021 daviddavid <daviddavid> 1:3.6.3-9.mga9
+ Revision: 1694931
- Update jansi dep to jansi1
- Remove unneeded commons-logging from runtime class path (rhbz#1883751)
- Also remove redundant commons-codec
- Adapt to cdi-api switch from jboss-interceptor to jakarta-interceptor

* Thu Jan 07 2021 neoclust <neoclust> 1:3.6.3-8.mga8
+ Revision: 1669546
- Rebuild against fixed velocity
- Revert "Adapt to cdi-api switch from jboss-interceptor to jakarta-interceptor"
- Adapt to cdi-api switch from jboss-interceptor to jakarta-interceptor.

* Fri Aug 28 2020 neoclust <neoclust> 1:3.6.3-7.mga8
+ Revision: 1619331
- Rebuild against new jar files
- Rebuild against new deps

* Wed Aug 19 2020 neoclust <neoclust> 1:3.6.3-4.mga8
+ Revision: 1616347
- Rebuild against new deps
- Rebuild after jakarta-annotation bootstrap
- Rebuild against some new maven deps

* Wed Aug 19 2020 neoclust <neoclust> 1:3.6.3-1.mga8
+ Revision: 1615524
- Switch jsr250 to jakarta-anntations
- New version 3.6.3

* Sun Aug 09 2020 neoclust <neoclust> 1:3.6.1-1.mga8
+ Revision: 1612229
- New version 3.6.1

* Sun Feb 16 2020 umeabot <umeabot> 1:3.5.4-4.mga8
+ Revision: 1536142
- Mageia 8 Mass Rebuild

* Tue Oct 15 2019 daviddavid <daviddavid> 1:3.5.4-3.mga8
+ Revision: 1453345
- Remove dependency on logback-classic

* Wed Aug 21 2019 daviddavid <daviddavid> 1:3.5.4-2.mga8
+ Revision: 1430970
- Update to Mockito 2

* Wed Dec 12 2018 neoclust <neoclust> 1:3.5.4-1.mga7
+ Revision: 1340660
- New version 3.5.4

* Sat Dec 08 2018 guillomovitch <guillomovitch> 3.5.2-1.mga7
+ Revision: 1338928
- new version 3.5.2

* Thu Nov 22 2018 guillomovitch <guillomovitch> 3.5.0-1.mga7
+ Revision: 1333419
- new version 3.5.0

* Tue Nov 20 2018 guillomovitch <guillomovitch> 3.3.9-17.mga7
+ Revision: 1332514
+ rebuild (emptylog)

* Tue Sep 18 2018 umeabot <umeabot> 3.3.9-16.mga7
+ Revision: 1263654
- Mageia 7 Mass Rebuild

* Sat May 13 2017 neoclust <neoclust> 3.3.9-15.mga6
+ Revision: 1100974
- Fix conflict

* Sun May 07 2017 neoclust <neoclust> 3.3.9-14.mga6
+ Revision: 1099547
- Add maven-lib subpackage

* Fri Apr 29 2016 daviddavid <daviddavid> 3.3.9-13.mga6
+ Revision: 1007667
- Force SLF4J SimpleLogger re-initialization
- Resolves: rhbz#1324832
+ neoclust <neoclust>
- Second rebuild of the java stack

* Tue Feb 23 2016 neoclust <neoclust> 3.3.9-11.mga6
+ Revision: 977336
- First rebuild of the java stack

* Sun Feb 21 2016 neoclust <neoclust> 3.3.9-10.mga6
+ Revision: 975273
- First rebuild of the bootstrap
- sync package maven with fedora
- Fix symlinks: add commons-lang3 and remove geronimo-annotation
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild
+ zezinho <zezinho>
- fix man
- new version
+ daviddavid <daviddavid>
- sync with fc24 (update to 3.3.3)
+ pterjan <pterjan>
- Obsolete apt-maven-plugin

* Tue Nov 04 2014 dmorgan <dmorgan> 3.2.2-3.mga5
+ Revision: 795486
- Fix Requires

* Thu Oct 30 2014 dmorgan <dmorgan> 3.2.2-2.mga5
+ Revision: 794717
- Rebuild after bootstrap
- New version

* Wed Oct 15 2014 umeabot <umeabot> 3.1.1-6.mga5
+ Revision: 743599
- Second Mageia 5 Mass Rebuild
+ pterjan <pterjan>
- Obsolete maven-ant-tasks which doesnot support maven3

* Fri Oct 03 2014 pterjan <pterjan> 3.1.1-5.mga5
+ Revision: 736267
- Revert workaround, the path is now correct
- Workaround jar files being install in /usr/lib instead of /usr/share
- Revert to 3.1.1
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild

* Mon Sep 08 2014 pterjan <pterjan> 3.2.3-1.mga5
+ Revision: 673492
- 3.2.3
- Sync with Fedora

* Wed Sep 03 2014 dmorgan <dmorgan> 3.1.1-4.mga5
+ Revision: 671690
- Fix Build with google-guice

* Sun Jun 15 2014 dmorgan <dmorgan> 3.1.1-3.mga5
+ Revision: 636501
- Add objectweb-pom as require

* Sun Jun 15 2014 dmorgan <dmorgan> 3.1.1-2.mga5
+ Revision: 636313
- Rebuild with fixed xmvn

* Sun Jun 15 2014 dmorgan <dmorgan> 3.1.1-1.mga5
+ Revision: 636300
- Remove use of OrderWithRequires for the moment
- Sync with fedora ( BR / Requires ).
- Fix patches
- New version
- Rebuild against current java stack
- Revert to version 3.1.0
- New version
+ joequant <joequant>
- rebuild to match dependencies

* Tue Jan 14 2014 dmorgan <dmorgan> 3.1.0-14.mga4
+ Revision: 566540
- Rebuild against fixed xbean

* Mon Dec 23 2013 dmorgan <dmorgan> 3.1.0-13.mga4
+ Revision: 560253
- Add maven-local as require for mageia4, we will finish BR migration for mga5

* Wed Dec 04 2013 joequant <joequant> 3.1.0-12.mga4
+ Revision: 555102
- add http-lightweight component which is necessary for server downloads

* Mon Oct 21 2013 umeabot <umeabot> 3.1.0-11.mga4
+ Revision: 539528
- Mageia 4 Mass Rebuild

* Mon Oct 07 2013 dmorgan <dmorgan> 3.1.0-10.mga4
+ Revision: 492381
- Rebuild against current jar

* Fri Sep 27 2013 dmorgan <dmorgan> 3.1.0-9.mga4
+ Revision: 487430
- Add patch for MNG-5503
- Resolves: rhbz#991454
- Build with easymock3

* Thu Sep 26 2013 dmorgan <dmorgan> 3.1.0-8.mga4
+ Revision: 486632
- Remove exclude

* Thu Sep 26 2013 dmorgan <dmorgan> 3.1.0-7.mga4
+ Revision: 486631
- Update Aether to 0.9.0.M3

* Mon Sep 23 2013 dmorgan <dmorgan> 3.1.0-6.mga4
+ Revision: 484382
- Synchronize JAR list in lib/ with upstream release
- Remove test dependencies on aopalliance and cglib
- Prepare for update to Aether 0.9.0.M3
- Install simplelogger.properties into %%{_sysconfdir}
- New version 3.1.0

* Wed Sep 18 2013 dmorgan <dmorgan> 3.0.5-10.mga4
+ Revision: 481232
- Use sonatype-aether symlinks

* Sat Jul 13 2013 dmorgan <dmorgan> 3.0.5-9.mga4
+ Revision: 453645
- Add codehaus-parent as Require in maven

* Sat Jul 13 2013 dmorgan <dmorgan> 3.0.5-8.mga4
+ Revision: 453618
- Requires maven-local during the transition

* Fri Jul 12 2013 dmorgan <dmorgan> 3.0.5-7.mga4
+ Revision: 453363
- New version

* Wed Jul 10 2013 dmorgan <dmorgan> 3.0.4-30.mga4
+ Revision: 452573
- In maven-script do not override M2_HOME if already set

* Sat Jan 12 2013 umeabot <umeabot> 3.0.4-29.mga3
+ Revision: 359569
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jan 06 2013 dmorgan <dmorgan> 3.0.4-28.mga3
+ Revision: 340011
- Add codehaus-parent as requires
+ pterjan <pterjan>
- Add missing BuildRequires

* Sat Dec 01 2012 dmorgan <dmorgan> 3.0.4-27.mga3
+ Revision: 324056
- Requires maven-local and remove files

* Wed Sep 12 2012 dmorgan <dmorgan> 3.0.4-4.mga3
+ Revision: 292648
- Sync with fedora maven

* Mon Sep 10 2012 dmorgan <dmorgan> 3.0.4-3.mga3
+ Revision: 291582
- Obsolete and provide maven2

* Mon Jul 16 2012 dmorgan <dmorgan> 3.0.4-2.mga3
+ Revision: 271275
- Make package noarch again to simplify bootstrapping

* Mon Jul 09 2012 dmorgan <dmorgan> 3.0.4-1.mga3
+ Revision: 268995
- Make javadoc noarch
- Make compilation source level 1.5
- Fix borked tarball unpacking (reason unknown)
- New version 3.0.4

* Mon Dec 26 2011 dmorgan <dmorgan> 3.0.3-15.mga2
+ Revision: 187695
- R/BR maven2-common-poms

* Fri Dec 23 2011 dmorgan <dmorgan> 3.0.3-14.mga2
+ Revision: 186275
- Fix test scope skipping ( From Fedora)

* Sat Dec 10 2011 dmorgan <dmorgan> 3.0.3-9.mga2
+ Revision: 180007
- Try to readd some deps

* Sat Dec 10 2011 dmorgan <dmorgan> 3.0.3-7.mga2
+ Revision: 179907
- Remove unnecessary deps causing problems from lib/
- Add utf-8 source encoding patch
- Disable debug package creation
- Change to arch specific since we are using _libdir for _jnidir
- Add bash completion (RHBZ #706856)

* Tue Jul 19 2011 dmorgan <dmorgan> 3.0.3-5.mga2
+ Revision: 126422
- Re enable maven-paret R/BR

* Tue Jul 19 2011 dmorgan <dmorgan> 3.0.3-4.mga2
+ Revision: 126392
- Disable R/BR for now
- Keep macros for now
- Backport fixes from fedora
- Fix handling of fallback default_poms
- Add empty-dep into maven package to not require maven2 version
- Process fragments in alphabetical order
- Add maven-parent to BR/R
- Add resolving from jnidir and java-jni
- Expect fragments in /usr/share/maven-fragments
- Resolve poms also from /usr/share/maven-poms
- Process fragments directly instead of maven2-depmap.xml(fedora)
- Add help to mvn-rpmbuild and mvn-local (rhbz#710448)
- Improve and clean up depmap handling for m2/m3 repos (fedora)

* Thu Apr 28 2011 dmorgan <dmorgan> 3.0.3-3.mga1
+ Revision: 93275
- Enable MAVEN_OPTS override in scripts ( From fedora )

* Thu Apr 28 2011 dmorgan <dmorgan> 3.0.3-2.mga1
+ Revision: 92622
- Rebuild after bootstrapping
- imported package maven


* Fri Mar  4 2011 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.0.3-1
- Update to 3.0.3
- Add ext subdirectory to lib

* Tue Mar  1 2011 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.0.3-0.1.rc1
- Update to 3.0.3rc1
- Enable tests again

* Thu Feb 10 2011 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.0.2-2
- Added mvn-rpmbuild script to be used in spec files
- mvn-local is now mixed mode (online with javadir priority)
- Changed mvn.jpp to mvn.local

* Fri Jan 28 2011 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.0.2-1
- Update to latest version (3.0.2)
- Ignore test failures temporarily

* Wed Jan 12 2011 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.0-6
- Fix bug #669034

* Tue Jan 11 2011 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.0-5
- Fix bugs #667625 #667614 and #667636
- Install maven metadata so they are not downloaded when mvn is run
- Rename mvn3-local to mvn-local
- Add more comments to resolver patch

* Tue Dec 21 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.0-4
- Add fedora local resolver
- Fix quoting of arguments to mvn scripts
- Add javadoc subpackage
- Make jars versionless and remove unneeded clean section

* Wed Dec  1 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.0-3
- Remove maven-ant-tasks jar in prep
- Make fragment file as %%config

* Tue Nov 16 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.0-2
- Added apache-commons-parent to BR after commons changes

* Tue Oct 12 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.0-1
- Initial package with vanilla maven (no jpp mode yet)
